#version 430

in vec4 clipSpace;
in vec2 textureCoordinates;

out vec4 out_Color;

uniform sampler2D reflectionTexture;
uniform sampler2D refractionTexture;
uniform sampler2D dudvMap;

uniform float moveFactor;

const float distortionStrength = 0.02;

void main(void)
{
	vec2 ndc = (clipSpace.xy / clipSpace.w) / 2.0 + 0.5;

	//Plane for Refraction
	vec2 refrTextureCoordinates = vec2(ndc.x, ndc.y);

	//Plane for Relection
	vec2 reflTextureCoordinates = vec2(ndc.x, 1-  ndc.y);
	
	vec2 distortion1 = (texture(dudvMap, vec2(textureCoordinates.x + moveFactor, textureCoordinates.y)).rg * 2.0 - 1.0) * distortionStrength;
	vec2 distortion2 = (texture(dudvMap, vec2(-textureCoordinates.x + moveFactor, textureCoordinates.y + moveFactor)).rg * 2.0 - 1.0) * distortionStrength;

	vec2 totalDistortion = distortion1 + distortion2;
	
	refrTextureCoordinates += totalDistortion;
	
	reflTextureCoordinates += totalDistortion;


	vec4 reflectColor = texture(reflectionTexture, reflTextureCoordinates);
	vec4 refractColor = texture(refractionTexture, refrTextureCoordinates);

	out_Color = mix(reflectColor, refractColor, 0.5);
	out_Color = mix(out_Color, vec4(0.0, 0.3, 0.5, 1.0), 0.2);
}